==> edencommon-2024.05.06.00.arm64_ventura.bottle.tar.gz: edencommon/2024.05.06.00/lib/cmake/edencommon/edencommon-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "edencommon::edencommon_os" for configuration "Release"
set_property(TARGET edencommon::edencommon_os APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_os PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_os.a"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_os )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_os "${_IMPORT_PREFIX}/lib/libedencommon_os.a" )

# Import target "edencommon::edencommon_telemetry" for configuration "Release"
set_property(TARGET edencommon::edencommon_telemetry APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_telemetry PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_telemetry.a"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_telemetry )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_telemetry "${_IMPORT_PREFIX}/lib/libedencommon_telemetry.a" )

# Import target "edencommon::edencommon_testharness" for configuration "Release"
set_property(TARGET edencommon::edencommon_testharness APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_testharness PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_testharness.a"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_testharness )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_testharness "${_IMPORT_PREFIX}/lib/libedencommon_testharness.a" )

# Import target "edencommon::edencommon_utils" for configuration "Release"
set_property(TARGET edencommon::edencommon_utils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_utils PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_utils.a"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_utils )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_utils "${_IMPORT_PREFIX}/lib/libedencommon_utils.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> edencommon-2024.12.02.00.arm64_ventura.bottle.tar.gz: edencommon/2024.12.02.00/lib/cmake/edencommon/edencommon-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "edencommon::edencommon_os" for configuration "Release"
set_property(TARGET edencommon::edencommon_os APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_os PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_os.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libedencommon_os.dylib"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_os )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_os "${_IMPORT_PREFIX}/lib/libedencommon_os.dylib" )

# Import target "edencommon::edencommon_telemetry" for configuration "Release"
set_property(TARGET edencommon::edencommon_telemetry APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_telemetry PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_telemetry.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libedencommon_telemetry.dylib"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_telemetry )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_telemetry "${_IMPORT_PREFIX}/lib/libedencommon_telemetry.dylib" )

# Import target "edencommon::edencommon_testharness" for configuration "Release"
set_property(TARGET edencommon::edencommon_testharness APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_testharness PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_testharness.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libedencommon_testharness.dylib"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_testharness )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_testharness "${_IMPORT_PREFIX}/lib/libedencommon_testharness.dylib" )

# Import target "edencommon::edencommon_utils" for configuration "Release"
set_property(TARGET edencommon::edencommon_utils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(edencommon::edencommon_utils PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libedencommon_utils.dylib"
  IMPORTED_SONAME_RELEASE "@rpath/libedencommon_utils.dylib"
  )

list(APPEND _cmake_import_check_targets edencommon::edencommon_utils )
list(APPEND _cmake_import_check_files_for_edencommon::edencommon_utils "${_IMPORT_PREFIX}/lib/libedencommon_utils.dylib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
